<!-- markdownlint-disable MD041 -->
{{ service_title() }}

This page gives an overview of the Malware & Virus Scanner (MVS), describing its current status,
where and how it's developed and deployed, and who is responsible for maintaining it.

## Service Description

The service provides an API for uploading & scanning files to detect whether they are safe or malicious.

Once a file has been uploaded via the API, it is queued for scanning by the service.

A client application can then poll the API to await or retrieve the scan results.

A file is considered "malicious" if it may contain a virus or malware.

The service is integrated with [API Gateway][api-gateway].

## Service Status

The service is currently in early user testing.

## Contact

Issues with the service functionality or new feature requests can be opened as a Gitlab Issue in
the [application project][gitlab-app].

Issues discovered with the deployment process or GCP infrastructure can be opened as a Gitlab Issue
in the [deployment project][gitlab-cloud-infra].

Other technical queries and support requests can be directed to Jackson Team via either of:

* [Team Email][jackson-email]
* [Team Chat][jackson-chat]

**NOTE:** This latter process will change to a HEAT ticket in the near future (Jun/Jul 2024).

## Environments

The service is currently deployed to the following environments,
each with [API Gateway][api-gateway] integration:

<!-- markdownlint-disable MD013 -->
| Name        | URL                                                     | Usage                                       |
|-------------|---------------------------------------------------------|---------------------------------------------|
| Development | <https://api.apps.cam.ac.uk/malware-virus-scanner-dev>  | Used only by the service developers.        |
| Staging     | <https://api.apps.cam.ac.uk/malware-virus-scanner-test> | Used for testing new features and releases. |
| Production  | <https://api.apps.cam.ac.uk/malware-virus-scanner>      | Live productionised service.                |
<!-- markdownlint-enable MD013 -->

## Source Code

The source code for this service consists of:

| Repository                           | Description                                         |
|--------------------------------------|-----------------------------------------------------|
| [Application][gitlab-app]            | The application itself i.e. micro-services & API.   |
| [Infrastructure][gitlab-cloud-infra] | Terraform & CI configuration for deployment to GCP. |

These repositories are configured in the [GitLab Project Factory][gitlab-project-factory-def].

## Technologies Used

| Technology              | Used For                             |
|-------------------------|--------------------------------------|
| Python                  | Programming language                 |
| Pydantic                | Data model definitions               |
| SQLAlchemy              | Database models & toolkit            |
| Alembic                 | Database migration toolkit           |
| Postgres                | Database implementation              |
| Fast API                | REST API (compliant with OpenAPI v3) |
| Docker & Docker Compose | Containerisation & Orchestration     |
| Terraform + GCP         | Cloud Provisioning & Platform        |

## Operational Documentation

The following gives an overview of how the service is deployed & maintained.

### User Guide

All current documentation consists of:

* This Guidebook page.
* The [application project][gitlab-app] and [deployment project][gitlab-cloud-infra] documents.
* The [OpenAPI specification][openapi-spec].

To suggest improvements or request additions, please open an issue in the [application project][gitlab-app].

### Access Control

Details on how to register a Client Application can be found in the [application project][gitlab-app]
under [Using the API][gitlab-app-user-guide].

### Deployment

Deployment to the GCP environment is via our standard terraform deployment CI pipeline.

### Monitoring

Monitoring is configured as per our standard Google Cloud Run application module.

{{ service_management() }}

[api-gateway]: https://developer.api.apps.cam.ac.uk/
[jackson-email]: mailto:devops-jackson@uis.cam.ac.uk
[jackson-chat]: https://teams.microsoft.com/l/channel/19%3Ac6f3dbdd296b4c7b988824208a9fb559%40thread.tacv2/Jackson%20Team?groupId=8b9ab893-3917-42bb-ba20-6cbd4bd2d304&tenantId=49a50445-bdfa-4b79-ade3-547b4f3986e9
[gitlab-app]: https://gitlab.developers.cam.ac.uk/uis/devops/malware-scanner-service/apps
[gitlab-app-user-guide]: https://gitlab.developers.cam.ac.uk/uis/devops/malware-scanner-service/apps/-/blob/main/docs/usage.md
[gitlab-cloud-infra]: https://gitlab.developers.cam.ac.uk/uis/devops/malware-scanner-service/infrastructure
[gitlab-project-factory-def]: https://gitlab.developers.cam.ac.uk/uis/devops/infra/gitlab-project-factory/-/tree/main/product-vars/malware-scanner
[openapi-spec]: https://gitlab.developers.cam.ac.uk/uis/devops/malware-scanner-service/apps/-/blob/main/docs/openapi.yaml
